@@ -64,12 +64,12 @@ void SyncedUserMetricsStore::sync() {
 		addDataSource(path);
 	}
 
-	QSharedPointer<canonical::usermetrics::UserData> systemData;
+	QSharedPointer<lomiri::usermetrics::UserData> systemData;
 
 	for (const QDBusObjectPath &path : m_interface.userDatas()) {
 
-		QSharedPointer<canonical::usermetrics::UserData> userData(
-				new canonical::usermetrics::UserData(DBusPaths::serviceName(),
+		QSharedPointer<lomiri::usermetrics::UserData> userData(
+				new lomiri::usermetrics::UserData(DBusPaths::serviceName(),
 						path.path(), m_interface.connection()));
 
 		QString username(userData->username());
@@ -89,7 +89,7 @@ void SyncedUserMetricsStore::sync() {
 }
 
 void SyncedUserMetricsStore::attachSystemData(
-		QSharedPointer<canonical::usermetrics::UserData> systemData) {
+		QSharedPointer<lomiri::usermetrics::UserData> systemData) {
 	for (UserDataPtr userData : m_userData.values()) {
 		SyncedUserData *syncedData = qobject_cast<SyncedUserData *>(
 				userData.data());
@@ -100,8 +100,8 @@ void SyncedUserMetricsStore::attachSystemData(
 void SyncedUserMetricsStore::addUserData(const QString &username,
 		const QDBusObjectPath &path) {
 
-	QSharedPointer<canonical::usermetrics::UserData> userData(
-			new canonical::usermetrics::UserData(DBusPaths::serviceName(),
+	QSharedPointer<lomiri::usermetrics::UserData> userData(
+			new lomiri::usermetrics::UserData(DBusPaths::serviceName(),
 					path.path(), m_interface.connection()));
 
 	// if we're adding system data for the first time, we must attach it
@@ -127,8 +127,8 @@ void SyncedUserMetricsStore::removeUserData(const QString &username,
 
 void SyncedUserMetricsStore::addDataSource(const QDBusObjectPath &path) {
 
-	QSharedPointer<canonical::usermetrics::DataSource> dataSource(
-			new canonical::usermetrics::DataSource(DBusPaths::serviceName(),
+	QSharedPointer<lomiri::usermetrics::DataSource> dataSource(
+			new lomiri::usermetrics::DataSource(DBusPaths::serviceName(),
 					path.path(), m_interface.connection()));
 
 	insert(path.path(),
