@@ -28,7 +28,7 @@ Metric::Metric(QObject *parent) :
 	try {
 		m_metricManager.reset(UserMetricsInput::MetricManager::getInstance());
 	} catch (std::exception &e) {
-		qWarning() << _("Failed to connect to metrics service:") << e.what();
+		qWarning() << _("Could not connect to metrics service:") << e.what();
 	}
 }
 
@@ -139,7 +139,7 @@ void Metric::registerMetric() {
 
 		m_metric = m_metricManager->add(parameters);
 	} catch (std::exception &e) {
-		qWarning() << _("Failed to register user metric:") << m_name << "\""
+		qWarning() << _("Could not register user metric:") << m_name << "\""
 				<< m_format << "\": " << e.what();
 	}
 }
@@ -152,7 +152,7 @@ void Metric::increment(double amount) {
 	try {
 		m_metric->increment(amount);
 	} catch (std::exception &e) {
-		qWarning() << _("Failed to increment metric:") << e.what();
+		qWarning() << _("Could not increment metric:") << e.what();
 	}
 }
 
@@ -164,7 +164,7 @@ void Metric::update(double value) {
 	try {
 		m_metric->update(value);
 	} catch (std::exception &e) {
-		qWarning() << _("Failed to update metric:") << e.what();
+		qWarning() << _("Could not update metric:") << e.what();
 	}
 }
 
